@@ -1,5 +1,5 @@
 ## data.R | ds4psy
-## hn | uni.kn | 2021 04 11
+## hn | uni.kn | 2022 04 07
 ## Documentation of datasets included in /data. 
 
 
@@ -289,14 +289,14 @@
 #' False-positive psychology: Undisclosed flexibility in data collection and analysis 
 #' allows presenting anything as significant. 
 #' \emph{Psychological Science}, \emph{22}(11), 1359--1366. 
-#' doi: \doi{10.1177/0956797611417632}
+#' doi: \code{10.1177/0956797611417632} 
 #' 
 #' \item Simmons, J.P., Nelson, L.D., & Simonsohn, U. (2014). 
 #' Data from paper "False-Positive Psychology: 
 #' Undisclosed Flexibility in Data Collection and Analysis 
 #' Allows Presenting Anything as Significant". 
 #' \emph{Journal of Open Psychology Data}, \emph{2}(1), e1. 
-#' doi: \doi{10.5334/jopd.aa} 
+#' doi: \code{10.5334/jopd.aa} 
 #' }
 #' 
 #' See files at \url{https://openpsychologydata.metajnl.com/articles/10.5334/jopd.aa/} and 
@@ -422,7 +422,7 @@
 
 #' Data import data_t1_de.
 #'
-#' \code{data_t1_de} is a fictitious dataset to practice data import 
+#' \code{data_t1_de} is a fictitious dataset to practice importing data  
 #' (from a CSV file, de/European style).  
 #' 
 #' @format A table with 20 cases (rows) and 4 variables (columns). 
@@ -451,7 +451,7 @@
 
 #' Data import data_t1_tab.
 #'
-#' \code{data_t1_tab} is a fictitious dataset to practice data import 
+#' \code{data_t1_tab} is a fictitious dataset to practice importing data  
 #' (from a TAB file).  
 #' 
 #' @format A table with 20 cases (rows) and 4 variables (columns). 
@@ -484,7 +484,7 @@
 
 #' Data import data_1.
 #'
-#' \code{data_1} is a fictitious dataset to practice data import 
+#' \code{data_1} is a fictitious dataset to practice importing data
 #' (from a DELIMITED file).  
 #' 
 #' @format A table with 100 cases (rows) and 4 variables (columns). 
@@ -520,7 +520,7 @@
 
 #' Data import data_2.
 #'
-#' \code{data_2} is a fictitious dataset to practice data import 
+#' \code{data_2} is a fictitious dataset to practice importing data  
 #' (from a FWF file).  
 #' 
 #' @format A table with 100 cases (rows) and 4 variables (columns). 
@@ -556,9 +556,9 @@
 
 #' Data table6.
 #'
-#' \code{table6} is a fictitious dataset to practice tidying data.
+#' \code{table6} is a fictitious dataset to practice reshaping and tidying data.
 #' 
-#' This dataset is a variant of the \code{table1} to \code{table5} datasets 
+#' This dataset is a further variant of the \code{table1} to \code{table5} datasets 
 #' of the \bold{tidyr} package.   
 #' 
 #' @format A table with 6 cases (rows) and 2 variables (columns). 
@@ -588,9 +588,9 @@
 
 #' Data table7.
 #'
-#' \code{table7} is a fictitious dataset to practice tidying data.
+#' \code{table7} is a fictitious dataset to practice reshaping and tidying data.
 #' 
-#' This dataset is a variant of the \code{table1} to \code{table5} datasets 
+#' This dataset is a further variant of the \code{table1} to \code{table5} datasets 
 #' of the \bold{tidyr} package.    
 #' 
 #' @format A table with 6 cases (rows) and 1 (horrendous) variable (column). 
@@ -620,9 +620,9 @@
 
 #' Data table8.
 #'
-#' \code{table8} is a fictitious dataset to practice tidying data.
+#' \code{table9} is a fictitious dataset to practice reshaping and tidying data.
 #' 
-#' This dataset is a variant of the \code{table1} to \code{table5} datasets 
+#' This dataset is a further variant of the \code{table1} to \code{table5} datasets 
 #' of the \bold{tidyr} package.     
 #' 
 #' @format A table with 3 cases (rows) and 5 variables (columns). 
@@ -635,6 +635,35 @@
 "table8"
 
 
+# (07c2) table9: The contingency table tidyr::table2 as a 3-dimensional array (xtabs) ------ 
+
+# # Data from tidyr::table1 as a contingency table (with a dedicated "count" variable): 
+# ct <- tidyr::table2  
+# 
+# # Create 3-dimensional array (xtabs < table):
+# table9 <- stats::xtabs(formula = count ~., data = ct)
+# dim(table9)  #  3 2 2
+# str(table9)
+# sum(table9)  # 2940985206
+
+
+#' Data table9.
+#'
+#' \code{table9} is a fictitious dataset to practice reshaping and tidying data.
+#' 
+#' This dataset is a further variant of the \code{table1} to \code{table5} datasets 
+#' of the \bold{tidyr} package.     
+#' 
+#' @format A 3 x 2 x 2 array (of type "xtabs") with 2940985206 elements (frequency counts). 
+#' 
+#' @family datasets
+#' 
+#' @source 
+#' Generated by using \code{stats::xtabs(formula = count ~., data = tidyr::table2)}. 
+
+"table9"
+
+
 # (07d) exp_wide.csv: ------ 
 
 # https://bookdown.org/hneth/ds4psy/7-5-tidy-ex.html
@@ -1035,7 +1064,7 @@
 #' @family datasets 
 #' 
 #' @source 
-#' Data originally based on \url{https://www.yourdictionary.com/slideshow/donald-trump-20-most-frequently-used-words.html} 
+#' Data originally based on a collection of \emph{Donald Trump's 20 most frequently used words} on \url{https://www.yourdictionary.com}  
 #' and expanded by interviews, public speeches, and Twitter tweets at \url{https://twitter.com/realDonaldTrump}. 
 
 "Trumpisms"
