@@ -1,12 +1,11 @@
 ## theme_fun.R | ds4psy
-## hn | uni.kn | 2021 03 31
+## hn | uni.kn | 2021 05 09 
 ## ---------------------------
 
 ## Functions for ggplot2 themes. 
 
 ## Themes: ---------- 
 
-
 # theme_empty: An empty/blank ggplot2 theme ------ 
 
 #' A basic and flexible plot theme (using ggplot2 and unikn).
@@ -30,6 +29,9 @@
 #' @param rel_small Relative size of smaller text. 
 #' Default: \code{rel_small = 10/12}. 
 #' 
+#' @param plot_mar Plot margin sizes (on top, right, bottom, left). 
+#' Default: \code{plot_mar = c(0, 0, 0, 0)} (in lines).  
+#' 
 #' @return A \bold{ggplot2} theme. 
 #' 
 #' @examples
@@ -41,12 +43,12 @@
 #' library('ggplot2')  # theme_empty() requires ggplot2
 #'    
 #' ggplot(datasets::iris) +
-#'   geom_jitter(aes(x = Petal.Length, y = Petal.Width, color = Species), size = 4, alpha = 1/2) +
+#'   geom_point(aes(x = Petal.Length, y = Petal.Width, color = Species), size = 4, alpha = 1/2) +
 #'   scale_color_manual(values = c("firebrick3", "deepskyblue3", "olivedrab3")) +
 #'   labs(title = "NOT SHOWN: Title",
 #'        subtitle = "NOT SHOWN: Subtitle", 
 #'        caption = "NOT SHOWN: Data from datasets::iris") +
-#'   theme_empty()
+#'   theme_empty(plot_mar = c(2, 0, 1, 0))  # margin lines (top, right, bot, left)
 #' 
 #' }
 #'   
@@ -62,11 +64,12 @@
 
 theme_empty <- function(font_size = 12, 
                         font_family = "", 
-                        rel_small = 12/14
+                        rel_small = 12/14,
+                        plot_mar = c(0, 0, 0, 0)  # plot margins (on top, right, bottom, left, in lines)  
 ){ # base on ggplot2::theme_void() in case the underlying ggplot2 code changes: 
   ggplot2::theme_void(base_size = font_size, base_family = font_family) %+replace%
     theme(#
-      # Elements in this block are not used directly, but inherited: 
+      # Elements in this block are not used directly, but inherited:
       line = element_blank(),
       rect = element_blank(),
       text = element_text(
@@ -100,7 +103,7 @@ theme_empty <- function(font_size = 12,
       legend.spacing.y =   NULL,
       legend.margin =      margin(0, 0, 0, 0),
       legend.key =         element_blank(),
-      legend.key.size =    unit(1.1*font_size, "pt"),
+      legend.key.size =    unit(1.1 * font_size, "pt"),
       legend.key.height =  NULL,
       legend.key.width =   NULL,
       legend.text =        element_text(size = rel(rel_small)),
@@ -124,7 +127,7 @@ theme_empty <- function(font_size = 12,
       panel.spacing =      unit(font_size / 2, "pt"),
       panel.spacing.x =    NULL,
       panel.spacing.y =    NULL,
-      panel.ontop    =     FALSE,
+      panel.ontop =        FALSE, 
       
       # strip: 
       strip.background =   element_blank(),
@@ -142,17 +145,16 @@ theme_empty <- function(font_size = 12,
       plot.title =         element_blank(),
       plot.subtitle =      element_blank(),
       plot.caption =       element_blank(),
-      plot.tag           = element_text(
-        face = "bold",
-        hjust = 0, vjust = 0.7
-      ),
+      plot.tag =           element_text(face = "bold", 
+                                        hjust = 0, vjust = 0.7),
       plot.tag.position = c(0, 1), 
-      plot.margin =        margin(0, 0, 0, 0),
+      # plot.margin =       margin(0, 0, 0, 0),
+      plot.margin = unit(plot_mar, "lines"),  # plot margins (top, right, bottom, left)  
       
       # note:   
       complete = TRUE
     )
-}
+} # theme_empty(). 
 
 
 # theme_ds4psy: A clean and flexible ggplot2 theme ------ 
@@ -337,12 +339,12 @@ theme_ds4psy <- function(base_size = 11,
       # panel.background = ggplot2::element_blank(),  # no panel background 
       panel.background = ggplot2::element_rect(fill = col_panel, color = NA), # panel background 
       # background:  
-      plot.background = ggplot2::element_rect(fill = col_bgrnd, color = NA), # main background
+      plot.background = ggplot2::element_rect(fill = col_bgrnd, color = NA),  # main background
       
-      # note:   
+      # note:
       complete = TRUE)
   
-} # theme_ds4psy end. 
+} # theme_ds4psy(). 
 
 
 # theme_grau: Alternative theme for ggplot2 ------ 
@@ -484,9 +486,15 @@ theme_clean <- function(base_size = 11,
       # note: 
       complete = TRUE)
   
-} # theme_clean end. 
+} # theme_clean().  
 
 
 ## ToDo: ----------
 
+# - Create an artsy/minimalist theme (e.g., theme_expo/theme_gallery), 
+#   (based on mixing theme_bw/theme_minimal/theme_void), that 
+#   - allows titles/caption/legend (like theme_void), but moves subtitle to bottom left,  
+#   - setting the size of panel margins (like theme_empty), 
+#   - and drawing a small border around panel or plot (like theme_ds4psy, unlike theme_empty). 
+
 ## eof. ----------------------
\ No newline at end of file
