@@ -1,5 +1,5 @@
 ## util_fun.R | ds4psy
-## hn | uni.kn | 2021 05 10
+## hn | uni.kn | 2022 01 02
 ## ---------------------------
 
 ## Utility functions. 
@@ -94,7 +94,7 @@ align_vec <- function(v_mod, v_fix){
 # align_vec(NA, 1:4)
 
 
-# align_vec_pair: Recycle a pair of vector to the length of the longer one: ------ 
+# align_vec_pair: Recycle a pair of vectors to the length of the longer one: ------ 
 
 # Return the pair of both vectors (as a list). 
 
@@ -825,6 +825,32 @@ kill_all <- function(){
 # kill_all()
 
 
+
+# get_name: Get an object's name (e.g., inside a function): ------ 
+
+get_name <- function(x){
+  
+  nm <- NA
+  
+  nm <- deparse(substitute(x))
+  
+  return(nm)
+  
+} # get_name
+
+# # Check:
+# nv <- 1:10
+# av <- letters[1:10]
+# (ls <- list(e1 = nv, e2 = av))
+# (df <- data.frame(v1 = nv, v2 = av))
+# (fc <- factor(av))
+# 
+# get_name(nv) # vector
+# get_name(ls) # list
+# get_name(df) # data.frame
+# get_name(fc) # factor
+
+
 ## ToDo: ----------
 
 # - etc.
